__all__ = [
    'OperationLogItem',
]
import toloka.client.primitives.base
import typing


class OperationLogItem(toloka.client.primitives.base.BaseTolokaObject):
    """An operation log item.

    If the operation was successful, the log contains the IDs of created objects, otherwise it contains validation errors details.

    Attributes:
        type: The type of the operation.
            * `USER_BONUS_PERSIST` — Successfully issuing a bonus.
            * `TASK_CREATE` — Successfully creating a task.
            * `TASK_SUITE_CREATE` — Successfully creating a task suite.
            * `USER_BONUS_VALIDATE` — Issuing a bonus that failed.
            * `TASK_VALIDATE` — Creating a task that failed.
            * `TASK_SUITE_VALIDATE` — Creating a task suite that failed.
        success: The operation result: success or failure.
        input: Input operation data.
        output: Operation output data. The content depends on the log item `type`.
    """

    def __init__(
        self,
        *,
        type: typing.Optional[str] = None,
        success: typing.Optional[bool] = None,
        input: typing.Optional[typing.Dict[str, typing.Any]] = None,
        output: typing.Optional[typing.Dict[str, typing.Any]] = None
    ) -> None:
        """Method generated by attrs for class OperationLogItem.
        """
        ...

    _unexpected: typing.Optional[typing.Dict[str, typing.Any]]
    type: typing.Optional[str]
    success: typing.Optional[bool]
    input: typing.Optional[typing.Dict[str, typing.Any]]
    output: typing.Optional[typing.Dict[str, typing.Any]]
