__all__ = [
    'Skill',
]
import datetime
import toloka.client.owner
import toloka.client.primitives.base
import typing


class Skill(toloka.client.primitives.base.BaseTolokaObject):
    """Some characteristic of a Toloker described by a number from 0 to 100.

    A `Skill` describes some characteristic, for example the percentage of correct responses.
    Skills can be used to filter Tolokers.

    Skill values are assigned to Tolokers by quality control rules, or manually. The values are accessed via the [UserSkill](toloka.client.user_skill.UserSkill.md) class.

    Learn more about the [Toloker skills](https://toloka.ai/docs/guide/nav/).

    Attributes:
        name: The skill name.
        public_name: The skill name visible to Tolokers. The name can be provided in several languages.
        public_requester_description: The skill description visible to Tolokers. The description can be provided in several languages.
        private_comment: Comments visible to a requester.
        hidden: Visibility of the skill values to Tolokers:
            * `True` — Tolokers don't see the information about the skill.
            * `False` — Tolokers see the name and the value of the assigned skill.

            Default value: `True`.
        skill_ttl_hours: A lifetime in hours. If the skill value assigned to a Toloker is not updated for `skill_ttl_hours`, the skill is removed from a Toloker's profile.
        training: Whether the skill is related to a training pool:
            * `True` — The skill value is set after completing a training pool.
            * `False` — The skill isn't related to a training pool.
        owner: The skill owner.
        id: The skill ID. Read-only field.
        created: The UTC date and time when the skill was created. Read-only field.

    Example:
        Creating a new skill if it doesn't exist.

        >>> segmentation_skill = next(toloka_client.get_skills(name='Road signs detection'), None)
        >>> if segmentation_skill:
        >>>     print(f'Skill exists. ID: {segmentation_skill.id}')
        >>> else:
        >>>     segmentation_skill = toloka_client.create_skill(
        >>>         name='Road signs detection',
        >>>         public_requester_description={
        >>>             'EN': 'The quality of selecting road signs on images',
        >>>             'RU': 'Качество выделения дорожных знаков на фотографиях',
        >>>         },
        >>>     )
        >>>     print(f'Skill created. ID: {segmentation_skill.id}')
        ...
    """

    def __init__(
        self,
        *,
        name: typing.Optional[str] = None,
        private_comment: typing.Optional[str] = None,
        hidden: typing.Optional[bool] = None,
        skill_ttl_hours: typing.Optional[int] = None,
        training: typing.Optional[bool] = None,
        public_name: typing.Optional[typing.Dict[str, str]] = None,
        public_requester_description: typing.Optional[typing.Dict[str, str]] = None,
        owner: typing.Optional[toloka.client.owner.Owner] = None,
        id: typing.Optional[str] = None,
        created: typing.Optional[datetime.datetime] = None
    ) -> None:
        """Method generated by attrs for class Skill.
        """
        ...

    _unexpected: typing.Optional[typing.Dict[str, typing.Any]]
    name: typing.Optional[str]
    private_comment: typing.Optional[str]
    hidden: typing.Optional[bool]
    skill_ttl_hours: typing.Optional[int]
    training: typing.Optional[bool]
    public_name: typing.Optional[typing.Dict[str, str]]
    public_requester_description: typing.Optional[typing.Dict[str, str]]
    owner: typing.Optional[toloka.client.owner.Owner]
    id: typing.Optional[str]
    created: typing.Optional[datetime.datetime]
