__all__ = [
    'SetUserSkillRequest',
    'UserSkill',
]
import datetime
import decimal
import toloka.client.primitives.base
import typing


class SetUserSkillRequest(toloka.client.primitives.base.BaseTolokaObject):
    """Parameters for setting a skill value for a Toloker.

    These parameters are used by the [set_user_skill](toloka.client.TolokaClient.set_user_skill.md) method.

    Attributes:
        user_id: The Toloker's ID.
        skill_id: The ID of the skill to set.
        value: The value of the skill. Allowed values: from 0 to 100.
    """

    def __init__(
        self,
        *,
        skill_id: typing.Optional[str] = None,
        user_id: typing.Optional[str] = None,
        value: typing.Optional[decimal.Decimal] = None
    ) -> None:
        """Method generated by attrs for class SetUserSkillRequest.
        """
        ...

    _unexpected: typing.Optional[typing.Dict[str, typing.Any]]
    skill_id: typing.Optional[str]
    user_id: typing.Optional[str]
    value: typing.Optional[decimal.Decimal]


class UserSkill(toloka.client.primitives.base.BaseTolokaObject):
    """A Toloker's skill value.

    Attributes:
        id: The ID of the Toloker's skill value.
        user_id: The ID of the Toloker.
        skill_id: The ID of the skill.
        exact_value: The fractional value of the skill. Allowed values: from 0 to 100.
        value: The value of the skill rounded to the nearest integer.
        created: The date and time when the skill was assigned the first time.
        modified: The date and time when the skill value was updated.
    """

    def __init__(
        self,
        *,
        id: typing.Optional[str] = None,
        skill_id: typing.Optional[str] = None,
        user_id: typing.Optional[str] = None,
        value: typing.Optional[int] = None,
        exact_value: typing.Optional[decimal.Decimal] = None,
        created: typing.Optional[datetime.datetime] = None,
        modified: typing.Optional[datetime.datetime] = None
    ) -> None:
        """Method generated by attrs for class UserSkill.
        """
        ...

    _unexpected: typing.Optional[typing.Dict[str, typing.Any]]
    id: typing.Optional[str]
    skill_id: typing.Optional[str]
    user_id: typing.Optional[str]
    value: typing.Optional[int]
    exact_value: typing.Optional[decimal.Decimal]
    created: typing.Optional[datetime.datetime]
    modified: typing.Optional[datetime.datetime]
