__all__ = [
    'WebhookSubscription',
]
import datetime
import toloka.client.primitives.base
import toloka.util._extendable_enum
import typing


class WebhookSubscription(toloka.client.primitives.base.BaseTolokaObject):
    """A subscription to an event in Toloka.

    For examples, you can receive notifications when a pool is closed or a task's status changes.
    Learn more about [notifications](https://toloka.ai/docs/api/using-webhook-subscriptions/).

    Attributes:
        id: The ID of the subscription. Read-only field.
        webhook_url: The URL to which notifications are sent.
        event_type: The event type.
        pool_id: The ID of the pool that the subscription was created for.
        created: The UTC date and time when the subscription was created. Read-only field.
    """

    class EventType(toloka.util._extendable_enum.ExtendableStrEnum):
        """An event type.

        Attributes:
            POOL_CLOSED: A pool is closed.
            DYNAMIC_OVERLAP_COMPLETED: An aggregated result is ready for a task with a dynamic overlap.
            ASSIGNMENT_CREATED: A task is created.
            ASSIGNMENT_SUBMITTED: A task is completed and waiting for acceptance by a requester.
            ASSIGNMENT_SKIPPED: A task was taken by a Toloker who skipped it and didn't return to it.
            ASSIGNMENT_EXPIRED: A task was taken by a Toloker who didn't complete it within the time limit or rejected it before it expired.
            ASSIGNMENT_APPROVED: A task was completed by a Toloker and approved by a requester.
            ASSIGNMENT_REJECTED: A task was completed by a Toloker but rejected by a requester.
        """

        POOL_CLOSED = 'POOL_CLOSED'
        DYNAMIC_OVERLAP_COMPLETED = 'DYNAMIC_OVERLAP_COMPLETED'
        ASSIGNMENT_CREATED = 'ASSIGNMENT_CREATED'
        ASSIGNMENT_SUBMITTED = 'ASSIGNMENT_SUBMITTED'
        ASSIGNMENT_SKIPPED = 'ASSIGNMENT_SKIPPED'
        ASSIGNMENT_EXPIRED = 'ASSIGNMENT_EXPIRED'
        ASSIGNMENT_APPROVED = 'ASSIGNMENT_APPROVED'
        ASSIGNMENT_REJECTED = 'ASSIGNMENT_REJECTED'

    def __init__(
        self,
        *,
        webhook_url: typing.Optional[str] = None,
        event_type: typing.Union[EventType, str, None] = None,
        pool_id: typing.Optional[str] = None,
        secret_key: typing.Optional[str] = None,
        id: typing.Optional[str] = None,
        created: typing.Optional[datetime.datetime] = None
    ) -> None:
        """Method generated by attrs for class WebhookSubscription.
        """
        ...

    _unexpected: typing.Optional[typing.Dict[str, typing.Any]]
    webhook_url: typing.Optional[str]
    event_type: typing.Optional[EventType]
    pool_id: typing.Optional[str]
    secret_key: typing.Optional[str]
    id: typing.Optional[str]
    created: typing.Optional[datetime.datetime]
